DELIMITER $$

CREATE SCHEMA `mysql_bug_repro` ;
$$

USE `mysql_bug_repro`;
$$


CREATE TABLE `documenttype` (
  `documenttypeUID` binary(16) NOT NULL DEFAULT '0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0',
  `documentTypeName` varchar(50) NOT NULL,
  `documentTypeExtension` varchar(50) NOT NULL,
  `isFiltered` tinyint(1) NOT NULL,
  `createdDateTime` datetime NOT NULL DEFAULT '1000-01-01 00:00:00',
  `modifiedDateTime` datetime NOT NULL DEFAULT '1000-01-01 00:00:00',
  `changeHistoryXml` text,
  `isActiveFlag` tinyint(1) NOT NULL DEFAULT '1',
  `wasAutoAddedFlag` tinyint(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`documenttypeUID`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1$$


CREATE TABLE `document` (
  `documentUID` binary(16) NOT NULL DEFAULT '0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0',
  `documentTypeUID` binary(16) NOT NULL,
  `filePath` varchar(255) NOT NULL,
  `fileName` varchar(255) NOT NULL,
  `fileByteSize` bigint(20) NOT NULL DEFAULT '0',
  `fileCheckSumSHA1` char(40) NOT NULL,
  `fileNDYPropertiesCheckSumSHA1` char(40) NOT NULL,
  `fileCreatedDateTime` datetime NOT NULL DEFAULT '1000-01-01 00:00:00',
  `fileModifiedDateTime` datetime NOT NULL DEFAULT '1000-01-01 00:00:00',
  `documentAuthor` varchar(255) NOT NULL,
  `documentTitle` varchar(255) NOT NULL,
  `documentRevision` varchar(50) NOT NULL,
  `autoSynopsis` varchar(500) CHARACTER SET utf8 DEFAULT NULL,
  `scanningServer` varchar(50) NOT NULL,
  `sourceDrive` varchar(255) NOT NULL,
  `scannedDateTime` datetime DEFAULT '1000-01-01 00:00:00',
  `refreshDateTime` datetime NOT NULL DEFAULT '1000-01-01 00:00:00',
  `createdDateTime` datetime NOT NULL DEFAULT '1000-01-01 00:00:00',
  `modifiedDateTime` datetime NOT NULL DEFAULT '1000-01-01 00:00:00',
  `changeHistoryXml` text,
  `isActiveFlag` tinyint(1) NOT NULL DEFAULT '1',
  `filePathUNC` varchar(1024) DEFAULT NULL,
  `officeName` varchar(50) NOT NULL,
  PRIMARY KEY (`documentUID`),
  KEY `fk_Document_DocumentType` (`documentTypeUID`),
  KEY `Idx_filePath` (`filePath`),
  KEY `Idx_filePathfileName` (`filePath`,`fileName`),
  KEY `Idx_fileCheckSumSHA1` (`fileCheckSumSHA1`),
  KEY `Idx_fileCreatedDateTime` (`fileCreatedDateTime`),
  KEY `Idx_fileModifiedDateTime` (`fileModifiedDateTime`),
  KEY `Idx_fileName` (`fileName`),
  CONSTRAINT `fk_Document_DocumentType` FOREIGN KEY (`documentTypeUID`) REFERENCES `documenttype` (`documentTypeUID`) ON DELETE NO ACTION ON UPDATE NO ACTION
) ENGINE=InnoDB DEFAULT CHARSET=latin1$$


CREATE TABLE `documentproperty` (
  `documentpropertyUID` binary(16) NOT NULL DEFAULT '0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0',
  `documentUID` binary(16) NOT NULL,
  `propertyName` varchar(100) NOT NULL,
  `propertyValue` varchar(8000) NOT NULL,
  `createdDateTime` datetime NOT NULL DEFAULT '1000-01-01 00:00:00',
  `modifiedDateTime` datetime NOT NULL DEFAULT '1000-01-01 00:00:00',
  `changeHistoryXml` text,
  `isActiveFlag` tinyint(1) NOT NULL DEFAULT '1',
  PRIMARY KEY (`documentpropertyUID`),
  KEY `Idx_PropertyName` (`propertyName`),
  KEY `Idx_PropertyNamePropertyValue` (`propertyName`,`propertyValue`(767)),
  KEY `fk_DocumentProperty_Document` (`documentUID`),
  CONSTRAINT `fk_DocumentProperty_Document` FOREIGN KEY (`documentUID`) REFERENCES `document` (`documentUID`) ON DELETE NO ACTION ON UPDATE NO ACTION
) ENGINE=InnoDB DEFAULT CHARSET=latin1$$


CREATE TABLE `searchcache` (
  `searchcacheUID` binary(16) NOT NULL DEFAULT '0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0',
  `searchCheckSumSHA1` char(40) NOT NULL,
  `searchSQL` varchar(8000) NOT NULL,
  `searchParameterCount` int(11) NOT NULL DEFAULT '0',
  `rowsFoundSQL` varchar(2000) NOT NULL,
  `rowsFoundParameterCount` int(11) NOT NULL DEFAULT '0',
  `insertTempPropertySQL` varchar(4000) NOT NULL,
  `totalRows` int(11) NOT NULL DEFAULT '-1',
  `totalRowsCached` int(11) NOT NULL DEFAULT '-1',
  `lastAccessDateTime` datetime NOT NULL DEFAULT '1000-01-01 00:00:00',
  `refreshDateTime` datetime NOT NULL DEFAULT '1000-01-01 00:00:00',
  `originalCreatedDateTime` datetime DEFAULT NULL,
  `modifiedDateTime` datetime NOT NULL DEFAULT '1000-01-01 00:00:00',
  `searchFrequency` int(11) NOT NULL DEFAULT '0',
  `createdDateTime` datetime NOT NULL DEFAULT '1000-01-01 00:00:00',
  `changeHistoryXml` text,
  `isActiveFlag` tinyint(1) NOT NULL DEFAULT '1',
  PRIMARY KEY (`searchcacheUID`),
  KEY `Idx_searchCacheUID` (`searchcacheUID`),
  KEY `Idx_searchCheckSumSHA1` (`searchCheckSumSHA1`),
  KEY `Idx_modifiedDateTime` (`modifiedDateTime`),
  KEY `Idx_refreshDateTime` (`refreshDateTime`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1$$


CREATE TABLE `searchresult` (
  `searchresultUID` binary(16) DEFAULT '0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0',
  `searchCacheUID` binary(16) NOT NULL,
  `documentUID` binary(16) NOT NULL,
  `score` double NOT NULL,
  `isMatchedFilenameFlag` tinyint(1) NOT NULL DEFAULT '0',
  `filePath` varchar(255) NOT NULL,
  `fileName` varchar(255) NOT NULL,
  `fileCheckSumSHA1` char(40) NOT NULL,
  `fileNDYPropertiesCheckSumSHA1` char(40) NOT NULL,
  `fileCreatedDateTime` datetime NOT NULL DEFAULT '1000-01-01 00:00:00',
  `fileModifiedDateTime` datetime NOT NULL DEFAULT '1000-01-01 00:00:00',
  `documentAuthor` varchar(255) NOT NULL,
  `documentTitle` varchar(255) NOT NULL,
  `documentRevision` varchar(50) NOT NULL,
  `documentTypeName` varchar(50) NOT NULL,
  `documentTypeExtension` varchar(50) DEFAULT NULL,
  `createdDateTime` datetime NOT NULL DEFAULT '1000-01-01 00:00:00',
  `modifiedDateTime` datetime NOT NULL DEFAULT '1000-01-01 00:00:00',
  `changeHistoryXml` text,
  `isActiveFlag` tinyint(1) NOT NULL DEFAULT '1',
  PRIMARY KEY (`searchCacheUID`,`documentUID`),
  KEY `Idx_SearchResult_DocumentScore` (`documentUID`,`score`),
  KEY `fk_SearchResult_SearchCache` (`searchCacheUID`),
  KEY `fk_SearchResult_Document` (`documentUID`),
  CONSTRAINT `fk_SearchResult_Document` FOREIGN KEY (`documentUID`) REFERENCES `document` (`documentUID`) ON DELETE NO ACTION ON UPDATE NO ACTION,
  CONSTRAINT `fk_SearchResult_SearchCache` FOREIGN KEY (`searchCacheUID`) REFERENCES `searchcache` (`searchCacheUID`) ON DELETE NO ACTION ON UPDATE NO ACTION
) ENGINE=InnoDB DEFAULT CHARSET=latin1$$


CREATE TABLE `documentthumbnail` (
  `documentthumbnailUID` binary(16) NOT NULL DEFAULT '0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0',
  `documentUID` binary(16) NOT NULL,
  `thumbnailImage` mediumblob NOT NULL,
  `createdDateTime` datetime NOT NULL DEFAULT '1000-01-01 00:00:00',
  `modifiedDateTime` datetime NOT NULL DEFAULT '1000-01-01 00:00:00',
  `changeHistoryXml` text,
  `isActiveFlag` tinyint(1) NOT NULL DEFAULT '1',
  PRIMARY KEY (`documentthumbnailUID`),
  KEY `fk_DocumentThumbnail_Document` (`documentUID`),
  CONSTRAINT `fk_DocumentThumbnail_Document` FOREIGN KEY (`documentUID`) REFERENCES `document` (`documentUID`) ON DELETE NO ACTION ON UPDATE NO ACTION
) ENGINE=InnoDB DEFAULT CHARSET=latin1$$








